@@ -1,5 +1,4 @@
-//go:build !windows
-// +build !windows
+//go:build unix
 
 package chezmoi
 
@@ -8,6 +7,8 @@ import (
 	"strings"
 )
 
+var devNullAbsPath = NewAbsPath("/dev/null")
+
 // NewAbsPathFromExtPath returns a new AbsPath by converting extPath to use
 // slashes, performing tilde expansion, and making the path absolute.
 func NewAbsPathFromExtPath(extPath string, homeDirAbsPath AbsPath) (AbsPath, error) {
