@@ -124,7 +124,6 @@ type SourceState struct {
 	defaultTemplateData     map[string]any
 	userTemplateData        map[string]any
 	priorityTemplateData    map[string]any
-	scriptEnv               []string
 	templateData            map[string]any
 	templateFuncs           template.FuncMap
 	templateOptions         []string
@@ -213,13 +212,6 @@ func WithReadTemplateData(readTemplateData bool) SourceStateOption {
 	}
 }
 
-// WithScriptEnv sets the script environment variables.
-func WithScriptEnv(scriptEnv []string) SourceStateOption {
-	return func(s *SourceState) {
-		s.scriptEnv = scriptEnv
-	}
-}
-
 // WithSourceDir sets the source directory.
 func WithSourceDir(sourceDirAbsPath AbsPath) SourceStateOption {
 	return func(s *SourceState) {
@@ -1911,7 +1903,6 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 
 			// Run the modifier on the current contents.
 			cmd := interpreter.ExecCommand(tempFile.Name())
-			cmd.Env = s.scriptEnv
 			cmd.Stdin = bytes.NewReader(currentContents)
 			cmd.Stderr = os.Stderr
 			contents, err = chezmoilog.LogCmdOutput(cmd)
