@@ -5,6 +5,8 @@ import (
 	"fmt"
 	"io/fs"
 	"sort"
+
+	"golang.org/x/exp/maps"
 )
 
 // A sourceStateEntryTreeNode is a node in a tree of SourceStateEntries.
@@ -45,13 +47,19 @@ func (n *sourceStateEntryTreeNode) GetNode(targetRelPath RelPath) *sourceStateEn
 }
 
 // ForEach calls f for each SourceStateEntry in the tree.
-func (n *sourceStateEntryTreeNode) ForEach(targetRelPath RelPath, f func(RelPath, SourceStateEntry) error) error {
-	return n.ForEachNode(targetRelPath, func(targetRelPath RelPath, node *sourceStateEntryTreeNode) error {
-		if node.sourceStateEntry == nil {
-			return nil
-		}
-		return f(targetRelPath, node.sourceStateEntry)
-	})
+func (n *sourceStateEntryTreeNode) ForEach(
+	targetRelPath RelPath,
+	f func(RelPath, SourceStateEntry) error,
+) error {
+	return n.ForEachNode(
+		targetRelPath,
+		func(targetRelPath RelPath, node *sourceStateEntryTreeNode) error {
+			if node.sourceStateEntry == nil {
+				return nil
+			}
+			return f(targetRelPath, node.sourceStateEntry)
+		},
+	)
 }
 
 // ForEachNode calls f for each node in the tree.
@@ -59,17 +67,13 @@ func (n *sourceStateEntryTreeNode) ForEachNode(
 	targetRelPath RelPath, f func(RelPath, *sourceStateEntryTreeNode) error,
 ) error {
 	switch err := f(targetRelPath, n); {
-	case errors.Is(err, Skip):
+	case errors.Is(err, fs.SkipDir):
 		return nil
 	case err != nil:
 		return err
 	}
 
-	childrenByRelPath := make(RelPaths, 0, len(n.children))
-	for childRelPath := range n.children {
-		childrenByRelPath = append(childrenByRelPath, childRelPath)
-	}
-
+	childrenByRelPath := RelPaths(maps.Keys(n.children))
 	sort.Sort(childrenByRelPath)
 	for _, childRelPath := range childrenByRelPath {
 		child := n.children[childRelPath]
@@ -94,7 +98,7 @@ func (n *sourceStateEntryTreeNode) Map() map[RelPath]SourceStateEntry {
 // MkdirAll creates SourceStateDirs for all components of targetRelPath if they
 // do not already exist and returns the SourceStateDir of relPath.
 func (n *sourceStateEntryTreeNode) MkdirAll(
-	targetRelPath RelPath, origin string, umask fs.FileMode,
+	targetRelPath RelPath, origin SourceStateOrigin, umask fs.FileMode,
 ) (*SourceStateDir, error) {
 	if targetRelPath == EmptyRelPath {
 		return nil, nil
@@ -136,7 +140,10 @@ func (n *sourceStateEntryTreeNode) MkdirAll(
 			var ok bool
 			sourceStateDir, ok = node.sourceStateEntry.(*SourceStateDir)
 			if !ok {
-				return nil, fmt.Errorf("%s: not a directory", componentRelPaths[0].Join(componentRelPaths[1:i+1]...))
+				return nil, fmt.Errorf(
+					"%s: not a directory",
+					componentRelPaths[0].Join(componentRelPaths[1:i+1]...),
+				)
 			}
 			sourceRelPath = sourceRelPath.Join(NewSourceRelPath(sourceStateDir.Attr.SourceName()))
 		}
