@@ -18,25 +18,47 @@ func (c *Config) newForgetCmd() *cobra.Command {
 		ValidArgsFunction: c.targetValidArgs,
 		Args:              cobra.MinimumNArgs(1),
 		RunE:              c.makeRunEWithSourceState(c.runForgetCmd),
-		Annotations: map[string]string{
-			modifiesSourceDirectory: "true",
-			persistentStateMode:     persistentStateModeReadWrite,
-		},
+		Annotations: newAnnotations(
+			modifiesSourceDirectory,
+			persistentStateModeReadWrite,
+		),
 	}
 
 	return forgetCmd
 }
 
-func (c *Config) runForgetCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
+func (c *Config) runForgetCmd(
+	cmd *cobra.Command,
+	args []string,
+	sourceState *chezmoi.SourceState,
+) error {
 	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{
-		mustBeInSourceState: true,
+		mustBeManaged: true,
 	})
 	if err != nil {
 		return err
 	}
 
+TARGET_REL_PATH:
 	for _, targetRelPath := range targetRelPaths {
-		sourceAbsPath := c.SourceDirAbsPath.Join(sourceState.MustEntry(targetRelPath).SourceRelPath().RelPath())
+		sourceStateEntry := sourceState.MustEntry(targetRelPath)
+
+		// Skip source state entries that are not regular entries. These are
+		// removes or externals, which we cannot handle.
+		switch sourceStateOrigin := sourceStateEntry.Origin(); sourceStateOrigin.(type) {
+		case chezmoi.SourceStateOriginAbsPath:
+			// OK, keep going.
+		case chezmoi.SourceStateOriginRemove:
+			c.errorf("warning: %s: cannot forget entry from remove\n", targetRelPath)
+			continue TARGET_REL_PATH
+		case *chezmoi.External:
+			c.errorf("warning: %s: cannot forget entry from external %s\n", targetRelPath, sourceStateOrigin.OriginString())
+			continue TARGET_REL_PATH
+		default:
+			panic(fmt.Sprintf("%s: %T: unknown source state origin type", targetRelPath, sourceStateOrigin))
+		}
+
+		sourceAbsPath := c.SourceDirAbsPath.Join(sourceStateEntry.SourceRelPath().RelPath())
 		if !c.force {
 			choice, err := c.promptChoice(fmt.Sprintf("Remove %s", sourceAbsPath), choicesYesNoAllQuit)
 			if err != nil {
